import React from 'react';


class RCNodePlayer extends React.Component {

    componentDidMount() {
        const { id, url, width, height, keepScreenOn, scaleMode, bufferTime, volume, autoplay, onRef } = this.props;
        let canvas = document.getElementById(id)
        if (width) {
            canvas.width = width
        }
        if (height) {
            canvas.height = height
        }
        if (onRef) {
            onRef(this)
        }
        window.NodePlayer.load(() => {
            this.player = new window.NodePlayer();
            this.player.setView(id);
            if (keepScreenOn) {
                this.player.setKeepScreenOn();
            }
            if (scaleMode) {
                this.player.setScaleMode(scaleMode);
            }
            if (bufferTime) {
                this.player.setBufferTime(bufferTime);
            }
            if (volume) {
                this.player.setVolume(volume);
            }
            if (autoplay) {
                this.player.start(url);
            }
        });
    }

    componentWillUnmount() {
        this.stop();
    }

    start(url) {
        if (this.player) {
            this.player.start(!!url ? url : this.props.url)
        }
    }

    stop() {
        if (this.player) {
            this.player.stop();
        }
    }

    setScaleMode(mode) {
        if (this.player) {
            this.player.setScaleMode(mode);
        }
    }

    setVolume(volume) {
        if (this.player) {
            this.player.setVolume(volume);
        }
    }

    fullscreen() {
        if (this.player) {
            this.player.fullscreen();
        }
    }

    render() {
        const { id, style } = this.props;
        return (
            <canvas id={id} style={style} />
        )
    }
}

export default RCNodePlayer;